dot-accumulate_snapshot_level: Accumulate ancestor chains for a single snapshot level

.accumulate_snapshot_levelR Documentation

Accumulate ancestor chains for a single snapshot level

Description

Accumulate ancestor chains for a single snapshot level

Usage

.accumulate_snapshot_level(cur_ancestors, snapshot, id_col, call)

Arguments

cur_ancestors

(list) A list of ancestor vectors for the current level, one per row.

snapshot

(list) A single snapshot object with elements data, ns, parent_ids, and child_sizes.

id_col

(character(1), integer(1), or symbol) The column that uniquely identifies each observation.

call

(environment) The environment to use for error messages.

Value

A list of ancestor vectors for the next level, where each vector is the ancestor vector of the parent row with the parent id appended.


tibblify documentation built on May 9, 2026, 5:07 p.m.