dot-apply_required: Apply required flags to a list of tib fields

.apply_requiredR Documentation

Apply required flags to a list of tib fields

Description

Apply required flags to a list of tib fields

Usage

.apply_required(fields, required)

Arguments

fields

(list) A named list of tib field specs.

required

(character) Names of required fields.

Value

(list) The same fields list with required = TRUE set on the named fields.


tibblify documentation built on May 9, 2026, 5:07 p.m.