dot-apply_spec_renaming: Rename list elements back to their original spec keys

.apply_spec_renamingR Documentation

Rename list elements back to their original spec keys

Description

Reverses tibblify's field renaming by mapping column names back to the original keys defined in spec.

Usage

.apply_spec_renaming(x, spec, call = caller_env())

Arguments

x

(any) The object to check.

spec

(tspec or NULL) A spec object describing the structure of x.

call

(environment) The environment to use for error messages.

Value

A named list with elements keyed by the original spec keys.


tibblify documentation built on May 9, 2026, 5:07 p.m.