dot-assemble_ancestors_col: Assemble the ancestors column for 'unnest_tree()' output

.assemble_ancestors_colR Documentation

Assemble the ancestors column for unnest_tree() output

Description

Assemble the ancestors column for unnest_tree() output

Usage

.assemble_ancestors_col(out, ancestors_to, tree_levels, call)

Arguments

out

(data.frame) The partially assembled output.

ancestors_to

(character(1)) The column name (NULL by default) in which to store the ids of the ancestors of a deeply nested child. Use NULL if you don't need this information.

tree_levels

(list) The object returned by .collect_tree_levels(), containing level_data, out_ptype, level_sizes, level_parent_ids, and level_ancestors.

call

(environment) The environment to use for error messages.

Value

A vector of ancestor ids with the same length as nrow(out).


tibblify documentation built on May 9, 2026, 5:07 p.m.