dot-assemble_level_col: Assemble the level column for 'unnest_tree()' output

.assemble_level_colR Documentation

Assemble the level column for unnest_tree() output

Description

Assemble the level column for unnest_tree() output

Usage

.assemble_level_col(out, level_to, level_data, call)

Arguments

out

(data.frame) The partially assembled output.

level_data

(list) Data frames collected at each tree level, without the child column.

call

(environment) The environment to use for error messages.

Value

An integer vector of levels with the same length as nrow(out).


tibblify documentation built on May 9, 2026, 5:07 p.m.