| .backtick | R Documentation |
Backtick-wrap a character vector
.backtick(x)
x |
( |
A character vector with each element wrapped in backticks and any existing backticks escaped with a backslash.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.