dot-check_col_values_missing: Check that a column has no missing values

.check_col_values_missingR Documentation

Check that a column has no missing values

Description

Check that a column has no missing values

Usage

.check_col_values_missing(x, x_arg, call = caller_env())

Arguments

x

(any) The object to check.

x_arg

(character(1)) The name of the x argument. This name will be mentioned in error messages as the input that is at the origin of a problem.

call

(environment) The environment to use for error messages.

Value

The input x.


tibblify documentation built on May 9, 2026, 5:07 p.m.