dot-check_id_col: Check that id column has no missing or duplicate values

.check_id_colR Documentation

Check that id column has no missing or duplicate values

Description

Check that id column has no missing or duplicate values

Usage

.check_id_col(id_col, x, call = caller_env())

Arguments

id_col

(character(1), integer(1), or symbol) The column that uniquely identifies each observation.

x

(any) The object to check.

call

(environment) The environment to use for error messages.

Value

The integer index of the id column.


tibblify documentation built on May 9, 2026, 5:07 p.m.