dot-check_parent_col: Check that parent column is valid and distinct from id column

.check_parent_colR Documentation

Check that parent column is valid and distinct from id column

Description

Check that parent column is valid and distinct from id column

Usage

.check_parent_col(parent_col, x, id_col, id_col_name, call = caller_env())

Arguments

parent_col

(character(1), integer(1), or symbol) The column that identifies the parent id of each observation. Each value must either be missing (for the root elements) or appear in the id_col column.

x

(any) The object to check.

id_col

(character(1), integer(1), or symbol) The column that uniquely identifies each observation.

id_col_name

(character(1)) The name of the column that uniquely identifies each observation.

call

(environment) The environment to use for error messages.

Value

The integer index of the parent column.


tibblify documentation built on May 9, 2026, 5:07 p.m.