dot-check_print_names_arg: Check and determine whether to print names for tibblifying

.check_print_names_argR Documentation

Check and determine whether to print names for tibblifying

Description

Check and determine whether to print names for tibblifying

Usage

.check_print_names_arg(names)

Arguments

names

(logical(1)) Should names be printed even if they can be deduced from the spec?

Value

A logical value indicating whether to print names for tibblifying, based on the provided names argument or the tibblify.print_names option if names is NULL.


tibblify documentation built on May 9, 2026, 5:07 p.m.