dot-check_unnest_col_diff: Validate an output column name and check it differs from...

.check_unnest_col_diffR Documentation

Validate an output column name and check it differs from prior names

Description

Validate an output column name and check it differs from prior names

Usage

.check_unnest_col_diff(
  col_name,
  x,
  ...,
  col_arg = caller_arg(col_name),
  call = caller_env()
)

Arguments

col_name

(character(1)) The name of the column.

x

(data.frame) The data frame to unnest.

...

Already-reserved column names that col_name must differ from.

col_arg

(character(1)) The name of the col argument, used for error messages.

call

(environment) The environment to use for error messages.

Value

col_name or NULL.


tibblify documentation built on May 9, 2026, 5:07 p.m.