dot-col_to_spec_df: Convert a df-typed list column to a tib_df specification

.col_to_spec_dfR Documentation

Convert a df-typed list column to a tib_df specification

Description

Delegates to .list_of_col_to_spec_df() or .non_list_of_col_to_spec_df() based on whether col is a list_of() column.

Usage

.col_to_spec_df(
  ptype,
  col,
  name,
  list_of_col,
  empty_list_unspecified,
  local_env
)

Arguments

ptype

(vector(0)) A prototype of the desired output type of the field.

col

(any) A column from a data frame, which may be a vector, a list, or a nested data frame.

name

(character(1)) The name of the field.

list_of_col

(logical(1)) Whether col is a list_of() column.

empty_list_unspecified

(logical(1)) Treat empty lists as unspecified?

local_env

(environment) A local environment used to track state across recursive calls, such as whether empty lists were encountered.

Value

A tib_df() specification.


tibblify documentation built on May 9, 2026, 5:07 p.m.