dot-df_col_to_spec: Convert a nested data frame column to a tib_row specification

.df_col_to_specR Documentation

Convert a nested data frame column to a tib_row specification

Description

Convert a nested data frame column to a tib_row specification

Usage

.df_col_to_spec(col, name, empty_list_unspecified, local_env)

Arguments

col

(any) A column from a data frame, which may be a vector, a list, or a nested data frame.

name

(character(1)) The name of the field.

empty_list_unspecified

(logical(1)) Treat empty lists as unspecified?

local_env

(environment) A local environment used to track state across recursive calls, such as whether empty lists were encountered.

Value

A tib_row() specification.


tibblify documentation built on May 9, 2026, 5:07 p.m.