dot-double_quote: Wrap a string in double quotes if it's not 'NULL'

.double_quoteR Documentation

Wrap a string in double quotes if it's not NULL

Description

Wrap a string in double quotes if it's not NULL

Usage

.double_quote(x)

Arguments

x

(character(1) or NULL) A string to wrap in double quotes, or NULL.

Value

The input string wrapped in double quotes if it was not NULL, or NULL.


tibblify documentation built on May 9, 2026, 5:07 p.m.