dot-fields_from_schema_properties: Extract tib fields from schema properties

.fields_from_schema_propertiesR Documentation

Extract tib fields from schema properties

Description

Extract tib fields from schema properties

Usage

.fields_from_schema_properties(schema, openapi_spec)

Arguments

schema

(list) A JSON schema object, as defined in the Schema Object, typically from openapi_spec$components$schemas or inline within the spec.

openapi_spec

(list) A parsed OpenAPI specification.

Value

A named list of tib field specs corresponding to the schema properties, with required flags applied.


tibblify documentation built on May 9, 2026, 5:07 p.m.