dot-guess_object_field_spec_expand_fields: Expand an object list into a tib spec

.guess_object_field_spec_expand_fieldsR Documentation

Expand an object list into a tib spec

Description

Expand an object list into a tib spec

Usage

.guess_object_field_spec_expand_fields(
  value,
  empty_list_unspecified,
  simplify_list,
  local_env,
  ...,
  tib_fn = tib_df,
  fields_fn = .guess_object_list_spec
)

Arguments

value

(list) An object list whose fields will be guessed.

empty_list_unspecified

(logical(1)) Treat empty lists as unspecified?

simplify_list

(logical(1)) Should scalar lists be simplified to vectors?

local_env

(environment) A local environment used to track state across recursive calls, such as whether empty lists were encountered.

...

Additional arguments passed to tib_fn.

tib_fn

(function) The tib constructor to wrap the fields in (e.g. tib_df() or tib_row()).

fields_fn

(function) The function used to generate field specs from value; defaults to .guess_object_list_spec().

Value

A tib spec created by tib_fn.


tibblify documentation built on May 9, 2026, 5:07 p.m.