dot-guess_object_list_field_spec_flat_to_vector: Guess a vector spec from a flat list of field values

.guess_object_list_field_spec_flat_to_vectorR Documentation

Guess a vector spec from a flat list of field values

Description

Guess a vector spec from a flat list of field values

Usage

.guess_object_list_field_spec_flat_to_vector(value_flat, name, ptype_result)

Arguments

value_flat

(list) The flattened values of a list field.

name

(character(1)) The name of the field.

ptype_result

(list) The result of .get_ptype_common() applied to value_flat.

Value

A tib_vector() spec.


tibblify documentation built on May 9, 2026, 5:07 p.m.