dot-guess_object_list_field_spec_vector: Guess the spec for a vector-typed field in an object list

.guess_object_list_field_spec_vectorR Documentation

Guess the spec for a vector-typed field in an object list

Description

Guess the spec for a vector-typed field in an object list

Usage

.guess_object_list_field_spec_vector(
  value,
  name,
  ptype,
  had_empty_lists,
  local_env
)

Arguments

value

(list) An object list whose fields will be guessed.

name

(character(1)) The name of the field.

ptype

(vector(0)) A prototype of the desired output type of the field.

had_empty_lists

(logical(1) or NULL) Whether empty lists were dropped when computing the common ptype.

local_env

(environment) A local environment used to track state across recursive calls, such as whether empty lists were encountered.

Value

A tib_scalar() or tib_vector() spec.


tibblify documentation built on May 9, 2026, 5:07 p.m.