dot-guess_vector_input_form: Guess whether a list field can be simplified to a vector spec

.guess_vector_input_formR Documentation

Guess whether a list field can be simplified to a vector spec

Description

Guess whether a list field can be simplified to a vector spec

Usage

.guess_vector_input_form(value, name)

Arguments

value

(list) An object list whose fields will be guessed.

name

(character(1)) The name of the field.

Value

A list with:

  • can_simplify (logical(1)): Whether the field can be simplified.

  • tib_spec: A tib field specification (present only when can_simplify is TRUE).


tibblify documentation built on May 9, 2026, 5:07 p.m.