dot-is_tib_name_canonical: Check if a tib field has a canonical name

.is_tib_name_canonicalR Documentation

Check if a tib field has a canonical name

Description

Check if a tib field has a canonical name

Usage

.is_tib_name_canonical(field, name)

Arguments

field

(list) A tib field.

name

(character(1)) The name to check against the field's key.

Value

TRUE if the field's key is a single string that matches name, FALSE otherwise.


tibblify documentation built on May 9, 2026, 5:07 p.m.