dot-is_url_string: Check whether input is an http(s) URL string

.is_url_stringR Documentation

Check whether input is an http(s) URL string

Description

Check whether input is an http(s) URL string

Usage

.is_url_string(x, arg = caller_arg(x), call = caller_env())

Arguments

x

(any) The object to check.

arg

(character(1)) An argument name. This name will be mentioned in error messages as the input that is at the origin of a problem.

call

(environment) The environment to use for error messages.

Value

(logical(1)) TRUE for scalar strings starting with ⁠http://⁠ or ⁠https://⁠, FALSE otherwise.


tibblify documentation built on May 9, 2026, 5:07 p.m.