dot-list_is_list_of_null: For each element, is it a list of NULLs?

.list_is_list_of_nullR Documentation

For each element, is it a list of NULLs?

Description

For each element, is it a list of NULLs?

Usage

.list_is_list_of_null(x)

Arguments

x

(any) The object to check.

Value

(logical) A logical vector the same length as x, where each element is TRUE if the corresponding element of x is itself a list of NULLs.


tibblify documentation built on May 9, 2026, 5:07 p.m.