dot-nchar_field_names: Calculate the number of characters in a field's name part

.nchar_field_namesR Documentation

Calculate the number of characters in a field's name part

Description

Calculate the number of characters in a field's name part

Usage

.nchar_field_names(fields)

Arguments

fields

(list or NULL) Fields to format.

Value

An integer vector of the number of characters in the name part of each field, including the "=" separator and a trailing comma.


tibblify documentation built on May 9, 2026, 5:07 p.m.