dot-nest_tree_lvl: Compute tree level for each element based on id and parent...

.nest_tree_lvlR Documentation

Compute tree level for each element based on id and parent relationships

Description

Compute tree level for each element based on id and parent relationships

Usage

.nest_tree_lvl(ids, parent_ids, id_col_name, call = caller_env())

Arguments

ids

(character or integer) The potential child ids to compare against.

parent_ids

(character or integer) The parent ids to check.

id_col_name

(character(1)) The name of the column that uniquely identifies each observation.

call

(environment) The environment to use for error messages.

Value

A list with lvls (integer vector of levels) and max_lvl (maximum level).


tibblify documentation built on May 9, 2026, 5:07 p.m.