dot-non_list_of_col_to_spec_df: Build field specs from a non-list_of df column

.non_list_of_col_to_spec_dfR Documentation

Build field specs from a non-list_of df column

Description

Build field specs from a non-list_of df column

Usage

.non_list_of_col_to_spec_df(col, ptype, empty_list_unspecified, local_env)

Arguments

col

(any) A column from a data frame, which may be a vector, a list, or a nested data frame.

ptype

(vector(0)) A prototype of the desired output type of the field.

empty_list_unspecified

(logical(1)) Treat empty lists as unspecified?

local_env

(environment) A local environment used to track state across recursive calls, such as whether empty lists were encountered.

Value

A named list of tib field specifications with required set.


tibblify documentation built on May 9, 2026, 5:07 p.m.