dot-parse_header_objects: Parse a named list of header objects from an OpenAPI spec

.parse_header_objectsR Documentation

Parse a named list of header objects from an OpenAPI spec

Description

Parse a named list of header objects from an OpenAPI spec

Usage

.parse_header_objects(header_objects, openapi_spec)

Arguments

header_objects

(list) A named list of header objects from an OpenAPI spec.

openapi_spec

(list) A parsed OpenAPI specification.

Value

(tbl_df) A tibble of parsed header objects.


tibblify documentation built on May 9, 2026, 5:07 p.m.