dot-parse_responses_object: Parse a responses object from an OpenAPI spec

.parse_responses_objectR Documentation

Parse a responses object from an OpenAPI spec

Description

Parse a responses object from an OpenAPI spec

Usage

.parse_responses_object(responses_object, openapi_spec)

Arguments

responses_object

(list) A responses object from an OpenAPI spec, mapping status codes to response objects, as defined in the Responses Object.

openapi_spec

(list) A parsed OpenAPI specification.

Value

(tbl_df) A tibble of parsed response objects with a status_code column.


tibblify documentation built on May 9, 2026, 5:07 p.m.