| .paste_multiline | R Documentation |
Pad and collapse a character vector across multiple lines
.paste_multiline(x)
x |
( |
A single string with the elements of x padded and collapsed across
multiple lines, with a leading newline and a trailing comma on each line.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.