dot-read_empty_list_argument: Read whether the empty list argument was used

.read_empty_list_argumentR Documentation

Read whether the empty list argument was used

Description

Read whether the empty list argument was used

Usage

.read_empty_list_argument(local_env)

Arguments

local_env

(environment) A local environment used to track state across recursive calls, such as whether empty lists were encountered.

Value

TRUE if local_env$empty_list_used is TRUE, FALSE otherwise.


tibblify documentation built on May 9, 2026, 5:07 p.m.