dot-read_schema: Read an OpenAPI schema from a file, connection, or list

.read_schemaR Documentation

Read an OpenAPI schema from a file, connection, or list

Description

Read an OpenAPI schema from a file, connection, or list

Usage

.read_schema(file, arg = caller_arg(file), call = caller_env())

Arguments

file

(character(1)) A path to a file, a connection, or literal data.

arg

(character(1)) An argument name. This name will be mentioned in error messages as the input that is at the origin of a problem.

call

(environment) The environment to use for error messages.

Value

(list) The parsed schema.


tibblify documentation built on May 9, 2026, 5:07 p.m.