dot-schema_has_ref: Check whether any nested list element has a $ref key

.schema_has_refR Documentation

Check whether any nested list element has a ⁠$ref⁠ key

Description

Check whether any nested list element has a ⁠$ref⁠ key

Usage

.schema_has_ref(x)

Arguments

x

(any) The object to check.

Value

(logical(1)) TRUE if any element has a ⁠$ref⁠ key.


tibblify documentation built on May 9, 2026, 5:07 p.m.