dot-shared-params: Shared parameters

.shared-paramsR Documentation

Shared parameters

Description

These parameters are used in multiple functions. They are defined here to make them easier to import and to find.

Arguments

allow_null

(logical(1)) Whether NULL is accepted.

arg

(character(1)) An argument name. This name will be mentioned in error messages as the input that is at the origin of a problem.

.call

(environment) The environment to use for error messages.

.children

(character(1)) The name of the field that contains the children.

.children_to

(character(1)) The column name in which to store the children.

col

(any) A column from a data frame, which may be a vector, a list, or a nested data frame.

col_name

(character(1)) The name of the column.

elt

(character or integer) An element of a path.

.elt_transform

(function or NULL) A function to apply to each element before casting to .ptype_inner.

empty_list_unspecified

(logical(1)) Treat empty lists as unspecified?

env

(environment) The environment used to evaluate glue fields in message.

.error_call

(environment) The environment to use for error messages.

expr

(any) An expression to evaluate and return, with indexed errors wrapped.

f_name

(character(1)) The (possibly ANSI-colored) function name.

field_spec

(tib_collector) A tibblify field collector.

file

(character(1)) A path to a file, a connection, or literal data.

.fill

(vector or NULL) Optionally, a value to use if the field does not exist. Note: this value must match the .ptype_inner of the field (the value before any transformation), not the .ptype.

force_names

(logical(1)) Should names be printed even if they can be deduced from the spec?

.format

(character(1) or NULL) Passed to the format argument of as.Date().

header_objects

(list) A named list of header objects from an OpenAPI spec.

id_col

(character(1), integer(1), or symbol) The column that uniquely identifies each observation.

id_col_name

(character(1)) The name of the column that uniquely identifies each observation.

index

(integer(1)) A zero-based location in a path.

inform_unspecified

(logical(1)) Inform about fields whose type could not be determined?

input_form

(character(1)) The input form string used in error messages.

.key

(character) The path of names to the field in the object.

local_env

(environment) A local environment used to track state across recursive calls, such as whether empty lists were encountered.

media_type_object

(list) A single media type object from an OpenAPI spec.

media_type_objects

(list) A named list of media type objects from an OpenAPI spec.

message

(character) A cli message template.

multi_line

(logical(1)) Should the output be formatted across multiple lines? For example, should each element of even a short list be displayed on its own line?

name

(character(1)) The name of the field.

name_spec

(character(1), function, or NULL) Name specification passed to vctrs::list_unchop().

names

(logical(1)) Should names be printed even if they can be deduced from the spec?

nchar_indent

(integer(1)) The number of (additional) characters that will be used to indent the output when multi_line = TRUE. Primarily for internal use when formatting is applied recursively.

openapi_spec

(list) A parsed OpenAPI specification.

operation_object

(list) An operation object from an OpenAPI spec, as defined in the Operation Object.

parameters

(list or NULL) A list of parameter objects from an OpenAPI spec, as defined in the Parameter Object.

parent_col

(character(1), integer(1), or symbol) The column that identifies the parent id of each observation. Each value must either be missing (for the root elements) or appear in the id_col column.

path

(list) A path object encoded as a depth and a list of path elements.

path_exp

(list) The path of the field used as the reference in size mismatch errors.

path_item_object

(list) A path item object from an OpenAPI spec, as defined in the Path Item Object.

.ptype

(vector(0)) A prototype of the desired output type of the field.

.ptype_inner

(vector(0)) A prototype of the input field.

request_body

(list or NULL) A request body object from an OpenAPI spec, as defined in the Request Body Object.

.required

(logical(1)) Throw an error if the field does not exist?

response_object

(list) A response object from an OpenAPI spec, as defined in the Response Object.

responses_object

(list) A responses object from an OpenAPI spec, mapping status codes to response objects, as defined in the Responses Object.

schema

(list) A JSON schema object, as defined in the Schema Object, typically from openapi_spec$components$schemas or inline within the spec.

simplify_list

(logical(1)) Should scalar lists be simplified to vectors?

size_act

(integer(1)) The observed size of a field.

size_exp

(integer(1)) The expected size of a field.

spec

(tspec or NULL) A spec object describing the structure of x.

spec_list

(list) A list of specifications.

tib_list

(list) A list of tib fields.

.transform

(function or NULL) A function to apply to the whole vector after casting to .ptype_inner.

value

(list) An object list whose fields will be guessed.

.values_to

(character(1) or NULL) For NULL (the default), the field is converted to a .ptype vector. If a string is provided, the field is converted to a tibble and the values go into the specified column.

width

(integer(1)) The width (in number of characters) of text output to generate.

x

(any) The object to check.

x_arg

(character(1)) The name of the x argument. This name will be mentioned in error messages as the input that is at the origin of a problem.


tibblify documentation built on May 9, 2026, 5:07 p.m.