dot-stabilize_values_to: Stabilize values_to argument

.stabilize_values_toR Documentation

Stabilize values_to argument

Description

Stabilize values_to argument

Usage

.stabilize_values_to(.values_to, .call)

Arguments

.values_to

(character(1) or NULL) For NULL (the default), the field is converted to a .ptype vector. If a string is provided, the field is converted to a tibble and the values go into the specified column.

.call

(environment) The environment to use for error messages.

Value

(character(1) or NULL) Validated .values_to.


tibblify documentation built on May 9, 2026, 5:07 p.m.