dot-stop_colmajor_null: Error for NULL in colmajor fields

.stop_colmajor_nullR Documentation

Error for NULL in colmajor fields

Description

Error for NULL in colmajor fields

Usage

.stop_colmajor_null(path)

Arguments

path

(list) A path object encoded as a depth and a list of path elements.

Value

NULL (invisibly). Called for its side effect of throwing an error.


tibblify documentation built on May 9, 2026, 5:07 p.m.