dot-stop_duplicate_name: Error for duplicate names

.stop_duplicate_nameR Documentation

Error for duplicate names

Description

Error for duplicate names

Usage

.stop_duplicate_name(path, name)

Arguments

path

(list) A path object encoded as a depth and a list of path elements.

name

(character(1)) The name of the field.

Value

NULL (invisibly). Called for its side effect of throwing an error.


tibblify documentation built on May 9, 2026, 5:07 p.m.