dot-stop_empty_name: Error for empty names

.stop_empty_nameR Documentation

Error for empty names

Description

Error for empty names

Usage

.stop_empty_name(path, index)

Arguments

path

(list) A path object encoded as a depth and a list of path elements.

index

(integer(1)) A zero-based location in a path.

Value

NULL (invisibly). Called for its side effect of throwing an error.


tibblify documentation built on May 9, 2026, 5:07 p.m.