dot-stop_non_list_element: Error for non-list element

.stop_non_list_elementR Documentation

Error for non-list element

Description

Error for non-list element

Usage

.stop_non_list_element(path, x)

Arguments

path

(list) A path object encoded as a depth and a list of path elements.

x

(any) The object to check.

Value

NULL (invisibly). Called for its side effect of throwing an error.


tibblify documentation built on May 9, 2026, 5:07 p.m.