dot-stop_object_vector_names_is_null: Error for unnamed object vector

.stop_object_vector_names_is_nullR Documentation

Error for unnamed object vector

Description

Error for unnamed object vector

Usage

.stop_object_vector_names_is_null(path)

Arguments

path

(list) A path object encoded as a depth and a list of path elements.

Value

NULL (invisibly). Called for its side effect of throwing an error.


tibblify documentation built on May 9, 2026, 5:07 p.m.