dot-stop_required_colmajor: Error for missing required colmajor field

.stop_required_colmajorR Documentation

Error for missing required colmajor field

Description

Error for missing required colmajor field

Usage

.stop_required_colmajor(path)

Arguments

path

(list) A path object encoded as a depth and a list of path elements.

Value

NULL (invisibly). Called for its side effect of throwing an error.


tibblify documentation built on May 9, 2026, 5:07 p.m.