dot-stop_scalar: Error for non-scalar field

.stop_scalarR Documentation

Error for non-scalar field

Description

Error for non-scalar field

Usage

.stop_scalar(path, size_act)

Arguments

path

(list) A path object encoded as a depth and a list of path elements.

size_act

(integer(1)) The observed size of a field.

Value

NULL (invisibly). Called for its side effect of throwing an error.


tibblify documentation built on May 9, 2026, 5:07 p.m.