dot-stop_vector_wrong_size_element: Error for wrong-sized vector element

.stop_vector_wrong_size_elementR Documentation

Error for wrong-sized vector element

Description

Error for wrong-sized vector element

Usage

.stop_vector_wrong_size_element(path, input_form, x)

Arguments

path

(list) A path object encoded as a depth and a list of path elements.

input_form

(character(1)) The input form string used in error messages.

x

(any) The object to check.

Value

NULL (invisibly). Called for its side effect of throwing an error.


tibblify documentation built on May 9, 2026, 5:07 p.m.