dot-tib_from_schema_array: Parse an array-type OpenAPI schema and create a tib field

.tib_from_schema_arrayR Documentation

Parse an array-type OpenAPI schema and create a tib field

Description

Parse an array-type OpenAPI schema and create a tib field

Usage

.tib_from_schema_array(schema, name, openapi_spec)

Arguments

schema

(list) A JSON schema object, as defined in the Schema Object, typically from openapi_spec$components$schemas or inline within the spec.

name

(character(1)) The name of the field.

openapi_spec

(list) A parsed OpenAPI specification.

Value

A tib field spec for the array, which may be a vector, data frame, or variant field depending on the array items schema.


tibblify documentation built on May 9, 2026, 5:07 p.m.