dot-tib_from_schema_type: Parse an OpenAPI schema type and create a tib field

.tib_from_schema_typeR Documentation

Parse an OpenAPI schema type and create a tib field

Description

Parse an OpenAPI schema type and create a tib field

Usage

.tib_from_schema_type(schema, name, openapi_spec)

Arguments

schema

(list) A JSON schema object, as defined in the Schema Object, typically from openapi_spec$components$schemas or inline within the spec.

name

(character(1)) The name of the field.

openapi_spec

(list) A parsed OpenAPI specification.

Value

A tib field spec corresponding to the schema type.


tibblify documentation built on May 9, 2026, 5:07 p.m.