dot-tibblify_width: Get the width for tibblifying

.tibblify_widthR Documentation

Get the width for tibblifying

Description

Get the width for tibblifying

Usage

.tibblify_width(width = NULL)

Arguments

width

(integer(1)) The width (in number of characters) of text output to generate.

Value

The width to use for tibblifying, either the provided width or the value of the width option if width is NULL.


tibblify documentation built on May 9, 2026, 5:07 p.m.