dot-tspec_from_schema_array: Convert an array-type schema to a tibblify data frame spec

.tspec_from_schema_arrayR Documentation

Convert an array-type schema to a tibblify data frame spec

Description

Convert an array-type schema to a tibblify data frame spec

Usage

.tspec_from_schema_array(schema, openapi_spec)

Arguments

schema

(list) A JSON schema object, as defined in the Schema Object, typically from openapi_spec$components$schemas or inline within the spec.

openapi_spec

(list) A parsed OpenAPI specification.

Value

A tspec_df() spec with fields extracted from the array items schema properties.


tibblify documentation built on May 9, 2026, 5:07 p.m.