dot-untibblify_df: Untibblify a data frame into a list of row lists

.untibblify_dfR Documentation

Untibblify a data frame into a list of row lists

Description

Untibblify a data frame into a list of row lists

Usage

.untibblify_df(x, spec, call = caller_env())

Arguments

x

(any) The object to check.

spec

(tspec or NULL) A spec object describing the structure of x.

call

(environment) The environment to use for error messages.

Value

A list with one named list per row of x.


tibblify documentation built on May 9, 2026, 5:07 p.m.