dot-untibblify_row: Untibblify a single data frame row into a named list

.untibblify_rowR Documentation

Untibblify a single data frame row into a named list

Description

Untibblify a single data frame row into a named list

Usage

.untibblify_row(x, spec, call = caller_env())

Arguments

x

(any) The object to check.

spec

(tspec or NULL) A spec object describing the structure of x.

call

(environment) The environment to use for error messages.

Value

A named list with one element per field of x.


tibblify documentation built on May 9, 2026, 5:07 p.m.