dot-vector_col_to_spec: Convert a vector column to a tib scalar or unspecified...

.vector_col_to_specR Documentation

Convert a vector column to a tib scalar or unspecified specification

Description

Convert a vector column to a tib scalar or unspecified specification

Usage

.vector_col_to_spec(col, name)

Arguments

col

(any) A column from a data frame, which may be a vector, a list, or a nested data frame.

name

(character(1)) The name of the field.

Value

A tib_scalar() or tib_unspecified() specification.


tibblify documentation built on May 9, 2026, 5:07 p.m.