| guess_tspec | R Documentation |
tibblify() specificationguess_tspec() automatically dispatches to the other guess_tspec_*()
functions based on the shape of the input. If you are unhappy with its
output, calling a specific guess_tspec_*() function may yield better
results, or at least clearer error messages about why that type isn't
supported.
Use guess_tspec_df() if the input is a data frame.
Use guess_tspec_object() if the input is an object (such as a JSON
object that has been read into R as a named list).
Use guess_tspec_object_list() if the input is a list of objects (such as
a JSON object that has been read into R as a list of named lists).
Use guess_tspec_list() if the input object is a list but you aren't sure
how it should be processed.
See vignette("supported-structures") for a discussion of the input types
supported by tibblify.
guess_tspec(
x,
...,
empty_list_unspecified = FALSE,
simplify_list = FALSE,
inform_unspecified = should_inform_unspecified(),
call = rlang::caller_env()
)
guess_tspec_df(
x,
...,
empty_list_unspecified = FALSE,
simplify_list = FALSE,
inform_unspecified = should_inform_unspecified(),
call = rlang::current_call(),
arg = rlang::caller_arg(x)
)
guess_tspec_list(
x,
...,
empty_list_unspecified = FALSE,
simplify_list = FALSE,
inform_unspecified = should_inform_unspecified(),
arg = caller_arg(x),
call = current_call()
)
guess_tspec_object(
x,
...,
empty_list_unspecified = FALSE,
simplify_list = FALSE,
inform_unspecified = should_inform_unspecified(),
call = rlang::current_call()
)
guess_tspec_object_list(
x,
...,
empty_list_unspecified = FALSE,
simplify_list = FALSE,
inform_unspecified = should_inform_unspecified(),
arg = caller_arg(x),
call = current_call()
)
x |
( |
... |
These dots are for future extensions and must be empty. |
empty_list_unspecified |
( |
simplify_list |
( |
inform_unspecified |
( |
call |
( |
arg |
( |
A specification object that can be used in tibblify().
guess_tspec(list(x = 1, y = "a"))
guess_tspec(list(list(x = 1), list(x = 2)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.