should_inform_unspecified: Determine whether to inform about unspecified fields in spec

View source: R/should_inform_unspecified.R

should_inform_unspecifiedR Documentation

Determine whether to inform about unspecified fields in spec

Description

Wrapper around getOption("tibblify.show_unspecified") to return TRUE unless the option is explicitly set to FALSE.

Usage

should_inform_unspecified()

Value

FALSE if the option is set to FALSE, TRUE otherwise.

Examples

should_inform_unspecified()

tibblify documentation built on May 9, 2026, 5:07 p.m.