tibblify-package: tibblify: Rectangle Nested Lists

tibblify-packageR Documentation

tibblify: Rectangle Nested Lists

Description

A tool to rectangle a nested list, that is to convert it into a 'tibble'. This is done automatically or according to a given specification. A common use case is for nested lists coming from parsing 'JSON' files, or the 'JSON' responses of 'REST' 'APIs'. 'Rectangling' uses the 'vctrs' package, and therefore offers a wide support of vector types.

Author(s)

Maintainer: Jon Harmon jonthegeek@gmail.com (ORCID)

Authors:

Other contributors:

  • Kirill Müller [contributor]

See Also

Useful links:


tibblify documentation built on May 9, 2026, 5:07 p.m.