untibblify: Convert a data frame or object into a nested list

View source: R/untibblify.R

untibblifyR Documentation

Convert a data frame or object into a nested list

Description

Convert a data frame or an object into a nested list. This is the inverse operation of tibblify(). See vignette("supported-structures") for a description of objects recognized by tibblify.

Usage

untibblify(x, spec = get_spec(x))

Arguments

x

(data.frame or object) An object to convert into a nested list.

spec

(tspec) Optional. A spec object which was used to create x. Defaults to the spec stored as the tib_spec attribute of x, if present.

Value

A nested list.

Examples

x <- tibble(
  a = 1:2,
  b = tibble(
    x = c("a", "b"),
    y = c(1.5, 2.5)
  )
)
untibblify(x)

tibblify documentation built on May 9, 2026, 5:07 p.m.