| .abort_not_tibblifiable | R Documentation |
Abort when x is neither an object nor a list of objects
.abort_not_tibblifiable(x, arg = caller_arg(x), call = caller_env())
x |
( |
arg |
( |
call |
( |
Nothing. Called for its side effect of throwing an error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.