| .accumulate_snapshot_level | R Documentation |
Accumulate ancestor chains for a single snapshot level
.accumulate_snapshot_level(cur_ancestors, snapshot, id_col, call)
cur_ancestors |
( |
snapshot |
( |
id_col |
( |
call |
( |
A list of ancestor vectors for the next level, where each vector is the ancestor vector of the parent row with the parent id appended.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.