| .apply_spec_renaming | R Documentation |
Reverses tibblify's field renaming by mapping column names back to the
original keys defined in spec.
.apply_spec_renaming(x, spec, call = caller_env())
x |
( |
spec |
( |
call |
( |
A named list with elements keyed by the original spec keys.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.