| .collapse_with_pad | R Documentation |
Collapse expressions with padding and optional multi-line formatting
.collapse_with_pad(x, multi_line, nchar_prefix = 0, width)
x |
( |
multi_line |
( |
nchar_prefix |
( |
width |
( |
A single string with the expressions collapsed, either on a single line or wrapped across multiple lines with indentation.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.