| .format_tib_parts | R Documentation |
Build the formatted argument string for a collector call
.format_tib_parts(
f_name,
x,
...,
.fill = NULL,
.ptype_inner = NULL,
.transform = NULL,
multi_line = FALSE,
nchar_indent = 0,
width = NULL,
names = FALSE
)
f_name |
( |
x |
A tibblify collector object. |
... |
Additional named arguments to include verbatim in the output,
forwarded from the calling |
.fill |
( |
.ptype_inner |
( |
.transform |
( |
multi_line |
( |
nchar_indent |
( |
width |
( |
names |
( |
(character(1)) A string of comma-separated, possibly wrapped
arguments ready to be placed inside the parentheses of the collector call.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.