| .get_ptype_common | R Documentation |
Find the common ptype of a list of objects
.get_ptype_common(x, empty_list_unspecified)
x |
( |
empty_list_unspecified |
( |
A list with component has_common_ptype (TRUE if so, FALSE
otherwise) and optional components ptype (an object representing the
common ptype, if there is one) and had_empty_lists (TRUE if
empty_list_unspecified is TRUE and the x input had such empty lists).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.