| .is_tib_name_canonical | R Documentation |
Check if a tib field has a canonical name
.is_tib_name_canonical(field, name)
field |
( |
name |
( |
TRUE if the field's key is a single string that matches name,
FALSE otherwise.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.