| .list_is_list_of_null | R Documentation |
For each element, is it a list of NULLs?
.list_is_list_of_null(x)
x |
( |
(logical) A logical vector the same length as x, where each
element is TRUE if the corresponding element of x is itself a list of
NULLs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.