| .nchar_field_names | R Documentation |
Calculate the number of characters in a field's name part
.nchar_field_names(fields)
fields |
( |
An integer vector of the number of characters in the name part of each field, including the "=" separator and a trailing comma.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.