| .pad | R Documentation |
Pad a character vector with a specified number of spaces
.pad(x, n)
x |
( |
n |
( |
A character vector with each element of x prepended with n
spaces. If an element of x contains newlines, each line will be prepended
with n spaces.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.