| .tibblify_width | R Documentation |
Get the width for tibblifying
.tibblify_width(width = NULL)
width |
( |
The width to use for tibblifying, either the provided width or the
value of the width option if width is NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.