| tibblify-package | R Documentation |
A tool to rectangle a nested list, that is to convert it into a 'tibble'. This is done automatically or according to a given specification. A common use case is for nested lists coming from parsing 'JSON' files, or the 'JSON' responses of 'REST' 'APIs'. 'Rectangling' uses the 'vctrs' package, and therefore offers a wide support of vector types.
Maintainer: Jon Harmon jonthegeek@gmail.com (ORCID)
Authors:
Jon Harmon jonthegeek@gmail.com (ORCID)
Maximilian Girlich maximilian.girlich@outlook.com [copyright holder]
Other contributors:
Kirill Müller [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.